var child_process = require('child_process');
var a_l = require('./a-l');

/*
root@raspberrypi3-e868ae:/# aplay -l
**** List of PLAYBACK Hardware Devices ****
card 1: sndrpihifiberry [snd_rpi_hifiberry_dacplus], device 0: HiFiBerry DAC+ HiFi pcm512x-hifi-0 []
  Subdevices: 1/1
  Subdevice #0: subdevice #0
card 2: ALSA [bcm2835 ALSA], device 0: bcm2835 ALSA [bcm2835 ALSA]
  Subdevices: 8/8
  Subdevice #0: subdevice #0
  Subdevice #1: subdevice #1
  Subdevice #2: subdevice #2
  Subdevice #3: subdevice #3
  Subdevice #4: subdevice #4
  Subdevice #5: subdevice #5
  Subdevice #6: subdevice #6
  Subdevice #7: subdevice #7
card 2: ALSA [bcm2835 ALSA], device 1: bcm2835 ALSA [bcm2835 IEC958/HDMI]
  Subdevices: 1/1
  Subdevice #0: subdevice #0
*/

function PlaybackDevice(metadata) {
  this.getCardNumber = function() { return metadata.cardNumber; };
  this.getDeviceNumber = function() { return metadata.deviceNumber; };
  this.getName = function() { return metadata.name; };
  this.getSubdeviceCount = function() { return metadata.subdeviceCount; };
}

var deviceCache = null;

function makeDeviceCache(cb) {
  child_process.exec('aplay -l', function(err, stdout) {
    // See if the command died
    if (err) {
      return cb(null, err);
    }

    deviceCache = [];
    var metadatas = a_l(stdout);
    metadatas.forEach(function(metadata) {
      deviceCache.push(new PlaybackDevice(metadata));
    })

    // Do the callback
    cb(deviceCache, null);
  });
}

module.exports = {
  getDevices: function(cb, forceRefresh) {
    if (deviceCache === null || forceRefresh) {
      makeDeviceCache(cb);
    } else {
      cb(deviceCache, null);
    }
  },
};
