var child_process = require('child_process');
var a_l = require('./a-l');

/*
root@raspberrypi3-e868ae:/# arecord -l
**** List of CAPTURE Hardware Devices ****
card 0: Device [USB PnP Sound Device], device 0: USB Audio [USB Audio]
  Subdevices: 1/1
  Subdevice #0: subdevice #0
*/

function RecordingDevice(metadata) {
  this.getCardNumber = function() { return metadata.cardNumber; };
  this.getDeviceNumber = function() { return metadata.deviceNumber; };
  this.getName = function() { return metadata.name; };
  this.getSubdeviceCount = function() { return metadata.subdeviceCount; };
}

var deviceCache = null;

function makeDeviceCache(cb) {
  child_process.exec('arecord -l', function(err, stdout) {
    // See if the command died
    if (err) {
      return cb(null, err);
    }
    
    deviceCache = [];
    var metadatas = a_l(stdout);
    metadatas.forEach(function(metadata) {
      deviceCache.push(new RecordingDevice(metadata));
    })

    // Do the callback
    cb(deviceCache, null);
  });
}

module.exports = {
  getDevices: function(cb, forceRefresh) {
    if (deviceCache === null || forceRefresh) {
      makeDeviceCache(cb);
    } else {
      cb(deviceCache, null);
    }
  },
};