var assert = require('chai').assert;
var sinon = require('sinon');

var child_process = require('child_process');
var aplay = require('../src/aplay');

var sandbox;

describe('aplay', function() {
  describe('getDevices', function() {
    beforeEach(function() {
      sandbox = sinon.sandbox.create();
    });

    afterEach(function() {
      sandbox.restore();
    });

    it('should return an empty list when only given 1 line from aplay -l', function(done) {
      sandbox.stub(child_process, 'exec', function(cmd, func) {
        func(null, '** First line **');
      });

      aplay.getDevices(function(actual, err) {
        assert.deepEqual([], actual);
        done();
      }, true);
    });

    it('should return 1 device when given 4 lines', function(done) {
      sandbox.stub(child_process, 'exec', function(cmd, func) {
        func(null, '**** List of PLAYBACK Hardware Devices ****\n\
card 1: sndrpihifiberry [snd_rpi_hifiberry_dacplus], device 0: HiFiBerry DAC+ HiFi pcm512x-hifi-0 []\n\
  Subdevices: 1/1\n\
  Subdevice #0: subdevice #0');
      });

      aplay.getDevices(function(actual, err) {
        assert.equal(1, actual.length);
        
        assert.equal(1, actual[0].getCardNumber());
        assert.equal(0, actual[0].getDeviceNumber());
        assert.equal('snd_rpi_hifiberry_dacplus', actual[0].getName());
        assert.equal(1, actual[0].getSubdeviceCount());

        done();
      }, true);
    });

    it('should return 3 devices when given lots of lines', function(done) {
      sandbox.stub(child_process, 'exec', function(cmd, func) {
        func(null, '**** List of PLAYBACK Hardware Devices ****\n\
card 1: sndrpihifiberry [snd_rpi_hifiberry_dacplus], device 0: HiFiBerry DAC+ HiFi pcm512x-hifi-0 []\n\
  Subdevices: 1/1\n\
  Subdevice #0: subdevice #0\n\
card 2: ALSA [bcm2835 ALSA], device 0: bcm2835 ALSA [bcm2835 ALSA]\n\
  Subdevices: 8/8\n\
  Subdevice #0: subdevice #0\n\
  Subdevice #1: subdevice #1\n\
  Subdevice #2: subdevice #2\n\
  Subdevice #3: subdevice #3\n\
  Subdevice #4: subdevice #4\n\
  Subdevice #5: subdevice #5\n\
  Subdevice #6: subdevice #6\n\
  Subdevice #7: subdevice #7\n\
card 2: ALSA [bcm2835 ALSA], device 1: bcm2835 ALSA [bcm2835 IEC958/HDMI]\n\
  Subdevices: 1/1\n\
  Subdevice #0: subdevice #0');
      });

      aplay.getDevices(function(actual, err) {
        assert.equal(3, actual.length);

        assert.equal(1, actual[0].getCardNumber());
        assert.equal(0, actual[0].getDeviceNumber());
        assert.equal('snd_rpi_hifiberry_dacplus', actual[0].getName());
        assert.equal(1, actual[0].getSubdeviceCount());

        assert.equal(2, actual[1].getCardNumber());
        assert.equal(0, actual[1].getDeviceNumber());
        assert.equal('bcm2835 ALSA', actual[1].getName());
        assert.equal(8, actual[1].getSubdeviceCount());

        assert.equal(2, actual[2].getCardNumber());
        assert.equal(1, actual[2].getDeviceNumber());
        assert.equal('bcm2835 ALSA', actual[2].getName());
        assert.equal(1, actual[2].getSubdeviceCount());

        done();
      }, true);
    });
  });
});
