var assert = require('chai').assert;
var sinon = require('sinon');

var child_process = require('child_process');
var arecord = require('../src/arecord');

var sandbox;

describe('arecord', function() {
  describe('getDevices', function() {
    beforeEach(function() {
      sandbox = sinon.sandbox.create();
    });

    afterEach(function() {
      sandbox.restore();
    });

    it('should return an empty list when only given 1 line from arecord -l', function(done) {
      sandbox.stub(child_process, 'exec', function(cmd, func) {
        func(null, '** First line **');
      });

      arecord.getDevices(function(actual, err) {
        assert.deepEqual([], actual);
        done();
      }, true);
    });

    it('should return 1 device when given 4 lines', function(done) {
      sandbox.stub(child_process, 'exec', function(cmd, func) {
        func(null, '**** List of CAPTURE Hardware Devices ****\n\
card 0: Device [USB PnP Sound Device], device 0: USB Audio [USB Audio]\n\
  Subdevices: 1/1\n\
  Subdevice #0: subdevice #0');
      });

      arecord.getDevices(function(actual, err) {
        assert.equal(1, actual.length);
        assert.equal(0, actual[0].getCardNumber());
        assert.equal(0, actual[0].getDeviceNumber());
        assert.equal('USB PnP Sound Device', actual[0].getName());
        assert.equal(1, actual[0].getSubdeviceCount());
        done();
      }, true);
    });
  });
});
